@@ -1,4 +1,4 @@
-export VN=0.35.1
+export VN=0.38
 export VER=klamav-$VN
 cd ..
 TOPDIR=$PWD
@@ -11,7 +11,7 @@ mkdir -p "$VER/Source Update"
 
 #create installer package
 cd "$VER/First Install/klamav"
-cvs -z3 -d:pserver:anonymous@cvs.sourceforge.net:/cvsroot/klamav co -P klamav
+cvs -z3 -d:ext:hoganrobert@klamav.cvs.sourceforge.net:/cvsroot/klamav co -P klamav
 mv klamav $VER
 cd $VER
 make -f Makefile.cvs
