@@ -155,10 +155,13 @@ Klamav::Klamav()
 	//klamdb->shouldIShow();
 
 	CollectionDB::instance()->insertEvent("Launch","KlamAV Launched");
+
+    setCaption(QString("KlamAV %1 (Using ClamAV %2)").arg(KLAMAV_VERSION).arg(KlamavConfig::clamAVVersion()));
 }
 	
 Klamav::~Klamav()
 {
+    KlamavConfig::writeConfig();
 	kapp->quit();
 }
 
@@ -197,6 +200,15 @@ void Klamav::contextEnable() {
 	//}
 }
 
+void Klamav::clamdStopped() {
+	if (freshklam->isFreshklamAlive())
+		_tray->setPixmap(KSystemTray::loadIcon("klamavbwdl"));
+	else
+		_tray->setPixmap(KSystemTray::loadIcon("klamavbw"));
+	DisableKlamd->setEnabled(FALSE);
+	EnableKlamd->setEnabled(TRUE);
+}
+
 void Klamav::contextDisable() {
 	klamd->slotCancel();
 	if (freshklam->isFreshklamAlive())
