@@ -13,16 +13,33 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #ifndef __MISC_H
 #define __MISC_H
 
+/* Maximum filenames under various systems - njh */
+#ifndef	NAME_MAX	/* e.g. Linux */
+# ifdef	MAXNAMELEN	/* e.g. Solaris */
+#   define	NAME_MAX	MAXNAMELEN
+# else
+#   ifdef	FILENAME_MAX	/* e.g. SCO */
+#     define	NAME_MAX	FILENAME_MAX
+#   endif
+# endif
+#endif
+
 #include "cfgparser.h"
 
 char *freshdbdir(void);
 void print_version(void);
 int filecopy(const char *src, const char *dest);
+int isnumb(const char *str);
+int rmdirs(const char *dirname);
+int dircopy(const char *src, const char *dest);
+int cvd_unpack(const char *cvd, const char *destdir);
+void daemonize(void);
 
 #endif
