@@ -37,7 +37,7 @@
 
 //#include "others.h"
 #include "cfgparser.h"
-//#include "memory.h"
+#include "memory.h"
 #include "options.h"
 #include "defaults.h"
 //#include "shared.h"
