@@ -4,6 +4,7 @@
 
 #include "klamav.h"
 #include "version.h"
+#include "klamavconfig.h"
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 
@@ -11,6 +12,7 @@ static const char *description =
     I18N_NOOP("KlamAV - Virus Protection for KDE");
 
 static const char *version = KLAMAV_VERSION;
+//static const char title[] = "KlamAV";
 
 static KCmdLineOptions options[] =
 {
@@ -21,7 +23,7 @@ static KCmdLineOptions options[] =
 
 int main(int argc, char **argv)
 {
-    KAboutData about("klamav", I18N_NOOP("KlamAV"), version, description,
+    KAboutData about("klamav", I18N_NOOP(""), version, description,
                      KAboutData::License_GPL, "(C) 2004 Robert Hogan", 0, 0, "robert at roberthogan dot net");
     about.addAuthor( "Robert Hogan", 0, "robert at roberthogan dot net" );
     KCmdLineArgs::init(argc, argv, &about);
