@@ -69,10 +69,10 @@ ScanViewer::ScanViewer(QWidget *parent, const char *name)
     resultview->setAllColumnsShowFocus(true);
     layout->addMultiCellWidget(resultview, 2, 2, 0, 2);
 
-	connect( resultview, SIGNAL(onItem ( QListViewItem * )),
-		SLOT(slotOnItem ( QListViewItem * )));
-	connect( resultview, SIGNAL(onViewport (  )),
-		SLOT(slotOffItem ( )));
+    connect( resultview, SIGNAL(onItem ( QListViewItem * )),
+        SLOT(slotOnItem ( QListViewItem * )));
+    connect( resultview, SIGNAL(onViewport (  )),
+        SLOT(slotOffItem ( )));
 
     menu = new QPopupMenu( resultview );
 
@@ -105,7 +105,7 @@ ScanViewer::ScanViewer(QWidget *parent, const char *name)
     
     status2_label = new QLabel(i18n("Files scanned: 0"), status2_frame);
     status2_layout->addWidget(status2_label, 10);
-	status2_label->hide();
+    status2_label->hide();
 
     prog = new KProgress(status2_frame);
     progosd = new K3bJobProgressOSD();
@@ -117,15 +117,15 @@ ScanViewer::ScanViewer(QWidget *parent, const char *name)
     prog->hide();
     progosd->hide();
 
- 	scan_time = new QPushButton( status2_frame );
-	scan_time->setText(i18n("Calculating Scan Time... (Click To By-Pass)"));
-	status2_layout->addWidget(scan_time,10);
- 	scan_time->adjustSize();
-	scan_time->show();
+     scan_time = new QPushButton( status2_frame );
+    scan_time->setText(i18n("Calculating Scan Time... (Click To By-Pass)"));
+    status2_layout->addWidget(scan_time,10);
+     scan_time->adjustSize();
+    scan_time->show();
 
     //status_frame->setPaletteBackgroundColor(QColor::Yellow);
-	connect( scan_time, SIGNAL(clicked()),
-		SLOT(slotCancelScanTime()) );
+    connect( scan_time, SIGNAL(clicked()),
+        SLOT(slotCancelScanTime()) );
 
 
 
@@ -171,21 +171,21 @@ void ScanViewer::processOutput()
         return;
 
     if ((showProgress) && prog->isHidden()){
-		status2_label->hide();
-		scan_time->hide();
-		prog->show();
+        status2_label->hide();
+        scan_time->hide();
+        prog->show();
         progosd->show();
     }
 
 
     //buf.replace("//","/"); // don't know why they're getting two slashes
-	while ((childproc) && ((pos = (childproc->readln(item2,true))) != -1)) {
+    while ((childproc) && ((pos = (childproc->readln(item2,true))) != -1)) {
             //item2 = (buf.section('\n',j,j)).stripWhiteSpace();
             item2 = item2.stripWhiteSpace();
             int fnameStartPoint = 0;
             int fnameEndPoint = item2.findRev(":");
             QString tmpFName = item2.mid(fnameStartPoint,(fnameEndPoint - fnameStartPoint));
-            
+
             if ((pos = (item2.find(" FOUND"))) != -1){
             //if ((pos = buf.section('\n',j,j).find("FOUND")) != -1){
                 QString tmpVirusName = item2.mid((fnameEndPoint+1),(item2.length() - (fnameEndPoint+1)));
@@ -201,13 +201,13 @@ void ScanViewer::processOutput()
                     tm->setPixmap( 0, SmallIcon("klamav") );
                     //resultview->insertItem(buf.section('\n',j,j));
                     QuarantineList.append(tmpFName+":"+tmpVirusName+suffix);
-	            CollectionDB::instance()->insertEvent("Virus Found",tmpVirusName,tmpFName);
+                CollectionDB::instance()->insertEvent("Virus Found",tmpVirusName,tmpFName);
 
                 }
-				filesscanned++;
-				if (!(showProgress))
-                	status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
-				
+                filesscanned++;
+                if (!(showProgress))
+                    status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
+                
             //}else if ((pos = buf.section('\n',j,j).find("ERROR:")) != -1){
             }else if ((pos = (item2.find("ERROR:"))) != -1){
                 QString tmpVirusName = item2.mid((fnameEndPoint+1),(item2.length() - (fnameEndPoint+1)));
@@ -216,52 +216,48 @@ void ScanViewer::processOutput()
                 CollectionDB::instance()->insertEvent("Error Found",tmpVirusName,tmpFName);
 
                 errorsEncountered = TRUE;
-				filesscanned++;
-				if (!(showProgress))
-                	status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
+                filesscanned++;
+                if (!(showProgress))
+                    status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
             //}else if ((pos = buf.section('\n',j,j).find("Scanning ")) != -1){
             }else if ((pos = (item2.find("Scanning"))) != -1){
                 if (status_label->palette() != QToolTip::palette())
                     status_label->setText(item2);
             //}else if ((pos = buf.section('\n',j,j).find(": OK")) != -1){
             }else if ((pos = (item2.find(": OK"))) != -1){
-				filesscanned++;
-				if (!(showProgress))
-                	status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
+                filesscanned++;
+                if (!(showProgress))
+                    status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
 
             //}else if ((pos = buf.section('\n',j,j).find(": Access denied")) != -1){
             }else if ((pos = (item2.find(": Access denied"))) != -1){
-				filesscanned++;
-				if (!(showProgress))
-                	status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
-				KNotifyClient::event(kmain->_tray->winId(),"ScanAccessDenied", QString("Can't scan %1 "
-					"- Access Denied!").arg(tmpFName));
+                filesscanned++;
+                if (!(showProgress))
+                    status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
+                KNotifyClient::event(kmain->_tray->winId(),"ScanAccessDenied", QString("Can't scan %1 "
+                    "- Access Denied!").arg(tmpFName));
                 CollectionDB::instance()->insertEvent("Error Found","Access Denied",tmpFName);
             //}else if ((pos = buf.section('\n',j,j).find(": Can't open")) != -1){
     
             }else if ((pos = (item2.find(": Can't open"))) != -1){
                 //status2_label->setText(i18n("Files scanned: %1").arg(++filesscanned));
-				filesscanned++;
-				if (!(showProgress))
-                	status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
-				KNotifyClient::event(kmain->_tray->winId(),"ScanAccessDenied", QString("Can't scan %1 "
-					"- Access Denied!").arg(tmpFName));
+                filesscanned++;
+                if (!(showProgress))
+                    status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
+                KNotifyClient::event(kmain->_tray->winId(),"ScanAccessDenied", QString("Can't scan %1 "
+                   "- Access Denied!").arg(tmpFName));
                 CollectionDB::instance()->insertEvent("Error Found","Access Denied",tmpFName);
-            //}else if ((pos = buf.section('\n',j,j).find(": Empty file")) != -1){
-
             }else if ((pos = (item2.find(": Empty file"))) != -1){
                 //status2_label->setText(i18n("Files scanned: %1").arg(++filesscanned));
-		filesscanned++;
-		if (!(showProgress))
-                	status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
-		//KNotifyClient::event(kmain->_tray->winId(),"ScanAccessDenied", QString("Can't scan %1 "
-		//			"- Empty File!").arg(tmpFName));
+                filesscanned++;
+                if (!(showProgress))
+                        status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
+            //KNotifyClient::event(kmain->_tray->winId(),"ScanAccessDenied", QString("Can't scan %1 "
+            //            "- Empty File!").arg(tmpFName));
                 CollectionDB::instance()->insertEvent("Error Found","Empty File",tmpFName);
-	    }
+            }
             item2 = "";
-	}
-        //kdDebug() << "out" << endl;
-//     buf = "";
+    }
 
     QString str;
     str.setNum(resultview->childCount());
@@ -270,7 +266,7 @@ void ScanViewer::processOutput()
     matches2_label->setText(str);
 
     if (showProgress){
-    	prog->setProgress (filesscanned);
+        prog->setProgress (filesscanned);
         progosd->setProgress ((int)(100 * (float)filesscanned/cnt));
     }
 
@@ -278,26 +274,37 @@ void ScanViewer::processOutput()
 }
 
 
-void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recursive)
+void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recursive, bool dcopscan)
 {
 
     //KMessageBox::information (this, filepattern);    
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    
+    if(( args->isSet( "scanthis" ) ) || (dcopscan)) {
+        calculateTime = FALSE;
+        showProgress = FALSE;
+        scan_time->hide();
+        status2_label->show();
+
+    }else{
+        calculateTime = TRUE;
+        showProgress = TRUE;
+        scan_time->show();
+        status2_label->hide();
+    }
+
     scanCancelled = FALSE;
-	showProgress = TRUE;
     scanInProgress = FALSE;
-	calculateTime = TRUE;
 
     m_mode = mode;
     m_filepattern = filepattern;
     m_recursive = recursive;
 
 
-	//kdDebug() << "m_filepattern *" << m_filepattern << "*" << endl;
+    //kdDebug() << "m_filepattern *" << m_filepattern << "*" << endl;
 
     prog->hide();
     progosd->hide();
-    status2_label->hide();
-    scan_time->show();
 
 
     matches2_label->setText("");
@@ -310,27 +317,28 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
     QStringList tmpfilepattern = filepattern;
 
     cnt = 0;
-	//QStringList temp = QStringList::split(" ", tmpfilepattern.replace("\"",""));
+    //QStringList temp = QStringList::split(" ", tmpfilepattern.replace("\"",""));
     //kdDebug() << temp << endl;
-    for ( QStringList::Iterator it = tmpfilepattern.begin(); it != tmpfilepattern.end(); ++it ){
-		QDir d( QString((*it).latin1()).stripWhiteSpace() );
-		kdDebug() << "dir " << QString((*it).latin1()).stripWhiteSpace() << endl;
-		counter = 0;
-        cnt = cnt + countFiles(d);
-    	if (scanCancelled)
-	       break;
-	}
-
+    if (calculateTime){
+        for ( QStringList::Iterator it = tmpfilepattern.begin(); it != tmpfilepattern.end(); ++it ){
+            QDir d( QString((*it).latin1()).stripWhiteSpace() );
+            kdDebug() << "dir " << QString((*it).latin1()).stripWhiteSpace() << endl;
+            counter = 0;
+            cnt = cnt + countFiles(d);
+            if (scanCancelled)
+            break;
+        }
+    }
     //kdDebug() << scanCancelled << endl;
 
     calculateTime = FALSE;
-	if (scanCancelled)
-		return;
+    if (scanCancelled)
+        return;
 
     //kdDebug() << filepattern << endl;
 
-	prog->setTotalSteps(cnt);
-	kdDebug() << "COUNT" << cnt << endl;	
+    prog->setTotalSteps(cnt);
+    kdDebug() << "COUNT" << cnt << endl;    
 
     config = KGlobal::config();
 
@@ -342,7 +350,6 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
     //status2_label->setText(i18n("Scan in Progress..."));
 
     QString db;
-    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     if(!( args->isSet( "scanthis" ) ) )
         db = kmain->freshklam->getCurrentDBDir();
@@ -492,8 +499,8 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
 
     
     childproc = new KProcIO();
-	childproc->setUseShell(TRUE);
-	childproc->setUsePty (KProcIO::Stdout,TRUE);
+    childproc->setUseShell(TRUE);
+    childproc->setUsePty (KProcIO::Stdout,TRUE);
 
     *childproc << "clamscan -v ";
     *childproc << excludes << " ";
@@ -507,13 +514,13 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
         SLOT(childExited()) );
     connect( childproc, SIGNAL(receivedStdout(KProcess *, char *, int)),
         SLOT(receivedOutput(KProcess *, char *, int)) );
-	childproc->start(KProcess::NotifyOnExit, KProcess::Stdout);*/
+    childproc->start(KProcess::NotifyOnExit, KProcess::Stdout);*/
 
-	connect( childproc, SIGNAL(readReady(KProcIO *)),
-		SLOT(receivedOutput(KProcIO *)) );
-	childproc->start(KProcIO::NotifyOnExit);
-	connect( childproc, SIGNAL(processExited(KProcess *)),
-			SLOT(childExited()) );
+    connect( childproc, SIGNAL(readReady(KProcIO *)),
+        SLOT(receivedOutput(KProcIO *)) );
+    childproc->start(KProcIO::NotifyOnExit);
+    connect( childproc, SIGNAL(processExited(KProcess *)),
+            SLOT(childExited()) );
 
     scanInProgress = TRUE;
 
@@ -533,7 +540,7 @@ void ScanViewer::finish()
         //processOutput();
         kdDebug() << "deleting childproc" << endl;
         delete childproc;
-    	childproc = 0;
+        childproc = 0;
         kdDebug() << "deleted childproc" << endl;
     }
 
@@ -543,14 +550,14 @@ void ScanViewer::finish()
     menu->setEnabled(TRUE);
     //dir_combo->setEnabled(TRUE);
 
-	scan_time->hide();
+    scan_time->hide();
     prog->hide();
     progosd->hide();
     progosd->saveSettings(KGlobal::config());
     status2_label->show();
 
     multiScan = FALSE;
-	calculateTime = FALSE;
+    calculateTime = FALSE;
 
     emit scanFinished(this);
 
@@ -651,7 +658,7 @@ void ScanViewer::receivedOutput(KProcIO *)
 {
     //buf += QCString(buffer, buflen+1);
     processOutput();
-   	//childproc->ackRead();
+       //childproc->ackRead();
 
 }
 
@@ -728,7 +735,7 @@ void  ScanViewer::Quarantine(){
                 (resultview->findItem(fname,0))->setText(2,"Quarantined");
                     (resultview->findItem(fname,0))->setPixmap( 0, SmallIcon("klamavbw") );
                 chmod((const char *)qname,0400);
-		CollectionDB::instance()->insertEvent("Quarantine",QString("Quarantined"),fname);
+        CollectionDB::instance()->insertEvent("Quarantine",QString("Quarantined"),fname);
 
             }else{
                 KMessageBox::information (this,i18n("<p>There was a problem quarantining <b>%1</b>. Check your diskspace, the permissions on your quarantine location and whether a file with the same name already exists in the quarantine. </p>").arg(fname));
@@ -755,7 +762,7 @@ void ScanViewer::slotRMB( QListViewItem* Item, const QPoint & point, int )
     QPixmap vlicon;
     QPixmap ticon;
 
-        QString iconPath = locate("cache", KMimeType::favIconForURL("http://viruspool.vanderkooij.org")+".png");
+        QString iconPath = locate("cache", KMimeType::favIconForURL("http://www.viruspool.net")+".png");
         if ( iconPath.isEmpty() )
           vicon = SmallIcon("find");
         else
@@ -844,7 +851,7 @@ void ScanViewer::slotStartAgain()
 {
     calculateTime = TRUE;
     emit scanStartingAgain(this);
-    slotScan(m_filepattern, m_mode, m_recursive);
+    slotScan(m_filepattern, m_mode, m_recursive,false);
     
 
 }
@@ -857,9 +864,9 @@ bool ScanViewer::scanGoingOn()
 void ScanViewer::slotCancelScanTime()
 {
     calculateTime = FALSE;
-	showProgress = FALSE;
-	status2_label->show();
-	scan_time->hide();
+    showProgress = FALSE;
+    status2_label->show();
+    scan_time->hide();
 
 }
 
@@ -867,56 +874,56 @@ void ScanViewer::slotCancelScanTime()
 // void ScanViewer::startProgress()
 // {
 // 
-// 	cnt = 0;
-// 	//kdDebug() << "m_filepattern" << m_filepattern << endl;
-// 	QDir d( m_filepattern );
-// //	int num = countFiles(d);
-// // 	if (countFiles(d) > 0)
-// //		//kdDebug() << "count" << num << endl;
+//     cnt = 0;
+//     //kdDebug() << "m_filepattern" << m_filepattern << endl;
+//     QDir d( m_filepattern );
+// //    int num = countFiles(d);
+// //     if (countFiles(d) > 0)
+// //        //kdDebug() << "count" << num << endl;
 // 
-// 	progress = new KProgressDialog (this, "progress", i18n( "Loading .." ), i18n( "Loading..." ), true);
-// 	progress->setAllowCancel(false);
-// 	prog = progress->progressBar();
-// 	progress->setLabel(i18n( "Loading lots and lots and lots of virus information" ));
-// 	//int cnt = countFiles(d);
-// 	prog->setTotalSteps(countFiles(d));
-// 	//kdDebug() << "COUNT" << countFiles(d) << endl;	
+//     progress = new KProgressDialog (this, "progress", i18n( "Loading .." ), i18n( "Loading..." ), true);
+//     progress->setAllowCancel(false);
+//     prog = progress->progressBar();
+//     progress->setLabel(i18n( "Loading lots and lots and lots of virus information" ));
+//     //int cnt = countFiles(d);
+//     prog->setTotalSteps(countFiles(d));
+//     //kdDebug() << "COUNT" << countFiles(d) << endl;    
 // 
 // }
 
 int ScanViewer::countFiles( QDir & root)
 {
 
-	kapp->processEvents();
+    kapp->processEvents();
 
-	if (!(calculateTime) || (scanCancelled)){
-// 		kapp->processEvents();
-		return 0;
-	}
-	QStringList entries = root.entryList( QDir::Dirs | QDir::Files | QDir::Hidden);
+    if (!(calculateTime) || (scanCancelled)){
+//         kapp->processEvents();
+        return 0;
+    }
+    QStringList entries = root.entryList( QDir::Dirs | QDir::Files | QDir::Hidden);
 
-	
-	////kdDebug() << "count" << counter << endl;	
-	for (QStringList::size_type j = 0; j < entries.size(); j++ )
-	{
-		QString entry = entries[j];
+    
+    ////kdDebug() << "count" << counter << endl;    
+    for (QStringList::size_type j = 0; j < entries.size(); j++ )
+    {
+        QString entry = entries[j];
 
-		if( entry == "." || entry == "..")
-			continue;
-		
+        if( entry == "." || entry == "..")
+            continue;
+        
 
-		QFileInfo fi(root, entry );
-		entry = fi.absFilePath();
-		entry = QDir::convertSeparators(entry);
+        QFileInfo fi(root, entry );
+        entry = fi.absFilePath();
+        entry = QDir::convertSeparators(entry);
 
-		if ((fi.isFile()) && !(fi.isSymLink())){
-			counter++;
-		}else if (fi.isDir()){
-			QDir temp(entry);
-			countFiles(temp);
-		}
-	}
-	return counter;
+        if ((fi.isFile()) && !(fi.isSymLink())){
+            counter++;
+        }else if ((fi.isDir()) && !(fi.isSymLink())){
+            QDir temp(entry);
+            countFiles(temp);
+        }
+    }
+    return counter;
 }
 
 void ScanViewer::startProgressDialog( const QString & text )
